#!/tools/bin/sh

echo === Binutils

cd /tmp &&
tar xvjf /sources/buildtools/binutils.tar.bz2 &&
mv binutils* binutils-src
sed -i -e 's@^NATIVE_LIB_DIRS.*@NATIVE_LIB_DIRS=/usr/lib@' binutils-src/ld/configure.tgt &&
mkdir binutils-build &&
cd binutils-build &&
../binutils-src/configure --prefix=/usr --enable-shared --disable-nls &&
make tooldir=/usr &&
make tooldir=/usr install &&
cp ../binutils-src/include/libiberty.h /usr/include &&
cd .. &&
rm -rf binutils-*

if [ $? -ne 0 ]; then exit 1; fi

echo === gcc

cd /tmp &&
tar xvjf /sources/buildtools/gcc-core.tar.bz2 &&
#tar xvjf buildtools/gcc-g++-4.0.2.tar.bz2 &&
mv gcc* gcc-src &&
cd gcc-src &&
# Do NOT run fixincludes (Replaces no_fixincludes patch from LFS)
sed -i -e 's@\./fixinc\.sh@-c true@' -e 's@.*include/README@	echo@' \
        gcc/Makefile.in &&
# Don't install libiberty, binutils already did.
sed -i "s/install:.*install-subdir/install: install-subdir/" libiberty/Makefile.in &&
# Adjust config entries from which spec file will be generated
for i in `find gcc/config -name "*.h"`
do
  sed -i -r -e 's /lib(64)?/ld(64)?(-linux)?(-x86-)?(-ia)?(64)?.so.[12] /lib/ld-uClibc.so.0 ' "$i"
  if [ $? -ne 0 ]; then exit 1; fi
done &&
mkdir ../gcc-build &&
cd ../gcc-build &&
../gcc-src/configure --prefix=/usr --enable-shared --enable-threads=posix --disable-nls --enable-languages=c && # --enable-__cxa_atexit --enable-clocale=gnu
make &&
make install &&
ln -s gcc /usr/bin/cc &&
cd .. &&
rm -rf gcc-*

if [ $? -ne 0 ]; then exit 1; fi

echo === make

cd /tmp &&
tar xvjf /sources/buildtools/make.tar.bz2 &&
cd make* &&
./configure --prefix=/usr &&
make &&
make install &&
cd .. &&
rm -rf make*

if [ $? -ne 0 ]; then exit 1; fi
